#ifndef APPEVENTLISTENER_HPP
#define APPEVENTLISTENER_HPP

#include <QObject>

#define APP_MESSAGE_SETWIDGET "Add widget"
#define APP_MESSAGE_CLOSE "Close"

class AppEventListener : public QObject
{
    Q_OBJECT

private:
    explicit AppEventListener(QObject *parent = 0);

public:
    static AppEventListener *instance();

public slots:
    void receiveMessage(const QString& message);

};

#endif // APPEVENTLISTENER_HPP
